@@ -28,7 +28,7 @@ def upsert_product_property(product, key, values, api_key=None,
     """
     assertions.datatype_str('product', product)
     return _upsert_property('products', product, key, values, api_key=api_key,
-                            **(request_kwargs or {}))
+                            request_kwargs=request_kwargs)
 
 
 def upsert_thng_property(thng, key, values, api_key=None, request_kwargs=None):
@@ -39,7 +39,7 @@ def upsert_thng_property(thng, key, values, api_key=None, request_kwargs=None):
     """
     assertions.datatype_str('thng', thng)
     return _upsert_property('thngs', thng, key, values, api_key=api_key,
-                            **(request_kwargs or {}))
+                            request_kwargs=request_kwargs)
 
 
 def _upsert_property(entity_type, entity_id, key, values, api_key=None,
@@ -69,7 +69,7 @@ def upsert_product_properties(product, key_values, api_key=None,
     for key_value in key_values:
         assertions.validate_field_specs(key_value, field_specs)
     return _upsert_properties('products', product, key_values, api_key=api_key,
-                              **(request_kwargs or {}))
+                              request_kwargs=request_kwargs)
 
 
 def upsert_thng_properties(thng, key_values, api_key=None, request_kwargs=None):
@@ -81,7 +81,7 @@ def upsert_thng_properties(thng, key_values, api_key=None, request_kwargs=None):
     for key_value in key_values:
         assertions.validate_field_specs(key_value, field_specs)
     return _upsert_properties('thngs', thng, key_values, api_key=api_key,
-                              **(request_kwargs or {}))
+                              request_kwargs=request_kwargs)
 
 
 def _upsert_properties(entity_type, entity_id, key_values, api_key=None,
@@ -124,7 +124,11 @@ def _read_property(evrythng, evrythng_type, property_name, timestamp_to=None,
     """Helper for reading properties."""
     assertions.datatype_str('property_name', property_name)
     url = '/{}/{}/properties/{}'.format(evrythng_type, evrythng, property_name)
-    query_params = (request_kwargs or {}).get('query_params', {})
+
+    if request_kwargs is None:
+        request_kwargs = {}
+
+    query_params = request_kwargs.get('query_params', {})
 
     if timestamp_from:
         assertions.datatype_time('timestamp', timestamp_from)
@@ -145,7 +149,7 @@ def read_product_property(product, property_name, timestamp_from=None,
     return _read_property(product, 'products', property_name,
                           timestamp_from=timestamp_from,
                           timestamp_to=timestamp_to, api_key=api_key,
-                          **(request_kwargs or {}))
+                          request_kwargs=request_kwargs)
 
 
 def read_thng_property(thng, property_name, timestamp_from=None,
@@ -155,7 +159,7 @@ def read_thng_property(thng, property_name, timestamp_from=None,
     return _read_property(thng, 'thngs', property_name,
                           timestamp_from=timestamp_from,
                           timestamp_to=timestamp_to, api_key=api_key,
-                          **(request_kwargs or {}))
+                          request_kwargs=request_kwargs)
 
 
 # Delete Properties
@@ -193,7 +197,7 @@ def delete_product_property(product, property_name, timestamp_from=None,
     return _delete_property(product, 'products', property_name,
                             timestamp_from=timestamp_from,
                             timestamp_to=timestamp_to, api_key=api_key,
-                            **(request_kwargs or {}))
+                            request_kwargs=request_kwargs)
 
 
 def delete_thng_property(thng, property_name, timestamp_from=None,
@@ -204,4 +208,4 @@ def delete_thng_property(thng, property_name, timestamp_from=None,
     return _delete_property(thng, 'thngs', property_name,
                             timestamp_from=timestamp_from,
                             timestamp_to=timestamp_to, api_key=api_key,
-                            **(request_kwargs or {}))
+                            request_kwargs=request_kwargs)
